@@ -22,11 +22,15 @@ def get_access_keys():
         WASABI_SECRET_KEY = os.environ["S3_SECRET_KEY"]
     except Exception as e:
         if "File" in str(e):
-            print("please configure wasabi_keys.cfg with 'key' and 'secret' key words")
+            print(
+                "please configure wasabi_keys.cfg with 'key' and 'secret' key words"
+            )
     return WASABI_ACCESS_KEY, WASABI_SECRET_KEY
 
 
-def sync_files(project_bucket_path, remote_directory_name, local_file_list, local_path):
+def sync_files(
+    project_bucket_path, remote_directory_name, local_file_list, local_path
+):
     """
     Summary: it creates a replica in local by checking local files and wasabi files
 
@@ -36,10 +40,24 @@ def sync_files(project_bucket_path, remote_directory_name, local_file_list, loca
         local_file_list (List): it is a list of files in local machine
     """
     # filtering the objects based on wasabi path
-    if len(list(project_bucket_path.objects.filter(Prefix=remote_directory_name))) != 0:
-        for obj in project_bucket_path.objects.filter(Prefix=remote_directory_name):
+    if (
+        len(
+            list(
+                project_bucket_path.objects.filter(
+                    Prefix=remote_directory_name
+                )
+            )
+        )
+        != 0
+    ):
+        for obj in project_bucket_path.objects.filter(
+            Prefix=remote_directory_name
+        ):
             # check if wasabi file exist in local or not
-            if str(obj.key).split(f"{remote_directory_name}")[-1] in local_file_list:
+            if (
+                str(obj.key).split(f"{remote_directory_name}")[-1]
+                in local_file_list
+            ):
                 logging.info(" - File exist in local")
             else:
                 if obj.size != 0:
@@ -47,8 +65,12 @@ def sync_files(project_bucket_path, remote_directory_name, local_file_list, loca
                     output_file = get_directory(
                         obj.key, local_path, remote_directory_name
                     )
-                    logging.info(f" Downloading file {obj.key} to {str(output_file)}")
-                    project_bucket_path.download_file(Filename=output_file, Key=obj.key)
+                    logging.info(
+                        f" Downloading file {obj.key} to {str(output_file)}"
+                    )
+                    project_bucket_path.download_file(
+                        Filename=output_file, Key=obj.key
+                    )
                 else:
                     logging.info("--skipping file as it is of size zero")
     else:
@@ -66,7 +88,14 @@ def get_directory(file_path, local_path, remote_directory_name):
     Returns:
         output_file (String): it is the output file path
     """
-    if len(file_path.split(f"{remote_directory_name}")[-1].strip("/").split("/")) > 1:
+    if (
+        len(
+            file_path.split(f"{remote_directory_name}")[-1]
+            .strip("/")
+            .split("/")
+        )
+        > 1
+    ):
         local_path = (
             local_path
             + "/"
@@ -102,12 +131,18 @@ def wasabi_sync_download(bucket_name, wasabi_path, local_path):
         aws_access_key_id=WASABI_ACCESS_KEY,
         aws_secret_access_key=WASABI_SECRET_KEY,
     )
-    s3 = session.resource("s3", endpoint_url="https://s3.eu-central-1.wasabisys.com")
+    s3 = session.resource(
+        "s3", endpoint_url="https://s3.eu-central-1.wasabisys.com"
+    )
     project_bucket_path = s3.Bucket(bucket_name)
     remote_directory_name = wasabi_path
     # checking local files
     local_path_file = list(Path(local_path).glob("**/*.*"))
     # creating file list
-    local_file_list = [str(i).split(f"{local_path}")[-1] for i in local_path_file]
-    sync_files(project_bucket_path, remote_directory_name, local_file_list, local_path)
+    local_file_list = [
+        str(i).split(f"{local_path}")[-1] for i in local_path_file
+    ]
+    sync_files(
+        project_bucket_path, remote_directory_name, local_file_list, local_path
+    )
     return True
